# -*- coding: utf-8 -*-

import urllib2
import urllib
import sys

from BeautifulSoup import BeautifulSoup

letras = {'á':'aacute','â':'acirc','ã':'atilde','é':'eacute',
        'ê':'ecirc','í':'iacute','ó':'oacute','ô':'ocirc','õ':'otilde',
        'ú':'uacute','ç':'ccedil'}

class LyricsTerra:
    
    def find(self,title, artist):
        self.title = title.lower().strip()
        self.artist = artist.lower().strip()
        title_find = self.title.replace(' ','+')
        pagina = urllib2.urlopen("http://letras.terra.com.br/?q=%s&tipo=1&busca=busca" % title_find)
        texto = pagina.read()
        pagina.close()
        link = self._parse_search(texto)
        if link:
            return self._parse_page_lyrics(link)
        else:
            return ''
        
    def _parse_search(self, texto):
        soup = BeautifulSoup(texto)
        t = soup.findAll('ul',{'class' :'res'})
        soup_lista = BeautifulSoup( str(t))
        t1 = soup_lista.findAll('li')
        busca = self._replace_symbols(self.artist) + ' - ' + \
            self._replace_symbols(self.title)
        for linha in t1:
            nome = str(linha.a.contents[0]).lower().strip()
            if nome == busca:
                return linha.a['href']
        return ''
        
        
    def _replace_symbols(self,text):
        texto = text
        for i in text:
            if '\xc3'+i in letras.keys():
                texto = texto.replace('\xc3'+i,'&'+letras['\xc3'+i]+';')
        return texto
        
    def _parse_page_lyrics(self,link):
        page_artista = urllib2.urlopen(link)
        pagina = page_artista.read()
        page_artista.close()
        soup = BeautifulSoup(pagina)
        t = soup.findAll('div', {'class':'ltr'})
        soup_local = BeautifulSoup(str(t))
        t1 = soup_local.findAll('p')
        return t1[1]
    
if __name__ == '__main__':
    if len(sys.argv) < 3:
        print 'usage: pylyricthons.py artista titulo'
        sys.exit()
    plugin = LyricsTerra()
    artista = sys.argv[1]
    titulo = sys.argv[2]
    texto = plugin.find(titulo, artista)
    print texto


import pkg_resources
import sys
from optparse import OptionParser

group_name = 'lyricsearch.search'

        
def command():
    usage = "usage: %prog [options] title artist"
    parser = OptionParser(usage)
    parser.add_option('-p','--plugin', action="store", dest="plugin",help='Select a plugin to search')
    parser.add_option('-l','--list', action="store_true", dest="lista", help='List plugins available')
    (options, args) = parser.parse_args()
    if options.lista:
        print 'Plugins availables:'
        for ep in pkg_resources.iter_entry_points(group_name):
            print '--',ep.name
        sys.exit()    
    if len(args) != 2:
        parser.error('incorrect number of arguments')
    title = args[0]
    artist = args[1]
    if options.plugin:
        for ep in pkg_resources.iter_entry_points(group_name):
            if ep.name == options.plugin:
                plugin_class = ep.load()
                b = plugin_class()
                texto = b.find(title, artist)
                if texto:
                    print texto
                    sys.exit()
        print ''
    entry_points = []
    for ep in pkg_resources.iter_entry_points(group_name):
        entry_points.append(ep)
    for ep in entry_points:
        plugin_class = ep.load()
        print 'procurando com:',ep.name
        b = plugin_class()
        texto = b.find(title, artist)
        if texto:
            print texto
            break
        
if __name__ == '__main__':
    command()


# -*- coding: utf-8 -*-
from setuptools import setup

PACKAGE = 'LyricSearch'
VERSION = '0.1.2'

setup(
    name = PACKAGE,
    version = VERSION,
    author = 'Claudio Torcato',
    author_email = 'clauditorcato@gmail.com',
    description = 'script for letter of music in web',
    classifiers = [
          'Development Status :: 4 - Beta',
          'Environment :: Console',
          'Intended Audience :: End Users/Desktop',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: POSIX',
          'Programming Language :: Python',
    ],
    packages = ['lyricsearch'],
    install_requires = [
        "BeautifulSoup >= 3.0.3"],    
    entry_points = """
    [lyricsearch.search]
    terra = lyricsearch.lyricterra:LyricsTerra
    [console_scripts]
    lyse = lyricsearch.lyse:command
    """
)